@@ -21,19 +21,26 @@
 #'
 #' @examples
 #'
-#' \dontrun{
+#' # just call `library(tidyverse)` at the top of the your script
 #' library(magrittr)
+#'
 #' cow_ddy %>% add_cow_alliance()
-#' }
+#'
 
 add_cow_alliance <- function(data) {
-  # require(dplyr)
-  # require(magrittr)
 
   if (length(attributes(data)$ps_data_type) > 0 && attributes(data)$ps_data_type == "dyad_year") {
+    if (!all(i <- c("ccode1", "ccode2") %in% colnames(data))) {
+
+      stop("add_cow_alliance() merges on two Correlates of War codes (ccode1, ccode2), which your data don't have right now. Make sure to run create_dyadyears() at the top of the pipe. You'll want the default option, which returns Correlates of War codes.")
+
+
+    } else {
     cow_alliance %>%
       left_join(data, .) %>%
-      mutate_at(vars("defense", "neutrality", "nonaggression", "entente"), ~ifelse(is.na(.), 0, .)) -> data
+      mutate_at(vars("cow_defense", "cow_neutral", "cow_nonagg", "cow_entente"), ~ifelse(is.na(.), 0, .)) -> data
+
+    }
 
 
   } else if (length(attributes(data)$ps_data_type) > 0 && attributes(data)$ps_data_type == "state_year") {
