@@ -30,18 +30,26 @@
 #'
 #' @examples
 #'
-#' \dontrun{
+#' # just call `library(tidyverse)` at the top of the your script
 #' library(magrittr)
+#'
 #' cow_ddy %>% add_democracy()
 #'
 #' create_stateyears() %>% add_democracy()
-#' }
+#'
 #'
 
 add_democracy <- function(data) {
 
   if (length(attributes(data)$ps_data_type) > 0 && attributes(data)$ps_data_type == "dyad_year") {
 
+    if (!all(i <- c("ccode1", "ccode2") %in% colnames(data))) {
+
+      stop("add_democracy() merges on two Correlates of War codes (ccode1, ccode2), which your data don't have right now. Make sure to run create_dyadyears() at the top of the pipe. You'll want the default option, which returns Correlates of War codes.")
+
+
+    } else {
+
     data %>% left_join(., ccode_democracy, by=c("ccode1"="ccode","year"="year")) %>%
       rename(v2x_polyarchy1 = .data$v2x_polyarchy,
              polity21 = .data$polity2,
@@ -51,13 +59,27 @@ add_democracy <- function(data) {
              polity22 = .data$polity2,
              xm_qudsest2 = .data$xm_qudsest) -> data
 
+      return(data)
+
+    }
 
 
   } else if (length(attributes(data)$ps_data_type) > 0 && attributes(data)$ps_data_type == "state_year") {
 
+    if (!all(i <- c("ccode") %in% colnames(data))) {
+
+      stop("add_democracy() merges on the Correlates of War codes (ccode), which your data don't have right now. Make sure to run create_stateyears() at the top of the pipe. You'll want the default option, which returns Correlates of War codes.")
+
+
+    } else {
+
     data %>%
       left_join(., ccode_democracy) -> data
 
+      return(data)
+
+    }
+
   } else  {
     stop("add_democracy() requires a data/tibble with attributes$ps_data_type of state_year or dyad_year. Try running create_dyadyears() or create_stateyears() at the start of the pipe.")
   }
