@@ -26,17 +26,25 @@
 #'
 #' @examples
 #'
-#' \dontrun{
+#' # just call `library(tidyverse)` at the top of the your script
 #' library(magrittr)
+#'
 #' cow_ddy %>% add_nmc()
 #'
 #' create_stateyears() %>% add_nmc()
-#' }
+#'
 #'
 add_nmc <- function(data) {
 
   if (length(attributes(data)$ps_data_type) > 0 && attributes(data)$ps_data_type == "dyad_year") {
 
+    if (!all(i <- c("ccode1", "ccode2") %in% colnames(data))) {
+
+      stop("add_nmc() merges on two Correlates of War codes (ccode1, ccode2), which your data don't have right now. Make sure to run create_dyadyears() at the top of the pipe. You'll want the default option, which returns Correlates of War codes.")
+
+
+    } else {
+
     data %>% left_join(., cow_nmc, by=c("ccode1"="ccode","year"="year")) %>%
       rename(milex1 = .data$milex,
              milper1 = .data$milper,
@@ -54,11 +62,27 @@ add_nmc <- function(data) {
              upop2 = .data$upop,
              cinc2 = .data$cinc) -> data
 
+      return(data)
+
+    }
+
 
   } else if (length(attributes(data)$ps_data_type) > 0 && attributes(data)$ps_data_type == "state_year") {
+
+    if (!all(i <- c("ccode") %in% colnames(data))) {
+
+      stop("add_nmc() merges on two Correlates of War codes (ccode1, ccode2), which your data don't have right now. Make sure to run create_dyadyears() at the top of the pipe. You'll want the default option, which returns Correlates of War codes.")
+
+
+    } else {
+
     data %>%
       left_join(., cow_nmc) -> data
 
+      return(data)
+
+    }
+
   } else  {
     stop("add_nmc() requires a data/tibble with attributes$ps_data_type of state_year or dyad_year. Try running create_dyadyears() or create_stateyears() at the start of the pipe.")
   }
