@@ -11,7 +11,9 @@ test_that("Dyad-year additions do not create duplicates", {
   expect_equal(nrow(cow_ddy), nrow(cow_ddy %>% add_cow_trade()))
   expect_equal(nrow(cow_ddy), nrow(cow_ddy %>% add_democracy()))
   expect_equal(nrow(cow_ddy), nrow(cow_ddy %>% add_gwcode_to_cow()))
-  expect_equal(nrow(cow_ddy), nrow(cow_ddy %>% add_mids()))
+  expect_equal(nrow(cow_ddy), nrow(cow_ddy %>% add_gml_mids()))
+  expect_equal(nrow(cow_ddy), nrow(cow_ddy %>% add_cow_mids()))
+  expect_equal(nrow(cow_ddy), nrow(cow_ddy %>% add_cow_mids() %>% add_gml_mids() %>% add_peace_years()))
   expect_equal(nrow(cow_ddy), nrow(cow_ddy %>% add_cow_alliance()))
   expect_equal(nrow(cow_ddy), nrow(cow_ddy %>% add_nmc()))
   expect_equal(nrow(cow_ddy), nrow(cow_ddy %>% add_archigos()))
